@@ -40,10 +40,24 @@
 #define MAXREAD 4096
 
 /* intervals betweens scan timeout checks
- the lower you use, faster the FDs are are freed at CPU usage expense
+ * the lower you use, faster the FDs are are freed at CPU usage expense
  */
 #define TIMEOUT_CHECK 5
 
 /* Drop the ircd connection if >IRC_READ_TIMEOUT
-   without getting data from ircd (seconds) */
-#define IRC_READ_TIMEOUT 120
+ *  without getting data from ircd (seconds) 
+ */
+#define IRC_READ_TIMEOUT 370
+
+/* Defines for how much time the cache for alreasy scanned hosts
+ * will be valid. (8 hours)
+ */ 
+#define CACHE_TIME (8*60*60)
+
+/* Check for open http proxies 
+ * This detects any proxy which allows GET to remote pages
+ */
+#undef SCAN_HTTP_GET
+#define SCAN_GET_URL  "http://some.localhost.net/page.html"
+#define SCAN_GET_HOST "some.localhost.net"
+
